@@ -188,7 +188,7 @@ class _PipfileBase:
         requirements_file = self.meta.to_requirements_index_conf()
 
         for package_version in self.packages.packages.values() if not develop else self.dev_packages.packages.values():
-            if package_version.version:
+            if package_version.version and package_version != "*":
                 requirements_file += f"{package_version.name}{package_version.version}\n"
             else:
                 requirements_file += f"{package_version.name}\n"
@@ -411,6 +411,7 @@ class Pipfile(_PipfileBase):
     def from_dict(cls, dict_) -> "Pipfile":
         """Retrieve instance of Pipfile from its dictionary representation."""
         _LOGGER.debug("Parsing Pipfile")
+        dict_ = dict(dict_)
         packages = dict_.pop("packages", {})
         dev_packages = dict_.pop("dev-packages", {})
         thoth_section = ThothPipfileSection.from_dict(dict_.pop("thoth", {}))
